GCSE RS Unit 3.2 (Part 3 of 5) Abortion | by MrMcMillanREvis

MrMcMillanREvis

GCSE RS Unit 3.2 (Part 3 of 5) Abortion | by MrMcMillanREvis

The 3rd of a series of videos designed for revising Topic 2 (Matters of Life and Death) from the Edexcel GCSE Religious Studies (Religious Education) Course. This is specifically for students studying Unit 3 (Religion and Life based on a study of Catholic Christianity). This third video looks at the controversial issue of Abortion. The other topics in this series are:
1. Catholic Beliefs About Life After Death http://youtu.be/sbRX43mrTdw
2. Other Beliefs About Life After Death http://youtu.be/CltMPfC_F1Q
4. Euthanasia http://youtu.be/pNQ1DStjGVg
5. World Poverty http://youtu.be/NFy-pYDVRiQ

29/09/2013